@@ -77,16 +77,58 @@ void shouldHandleLogin()
   fakeServer.setScenario( scenario );
   fakeServer.startAndWait();
 
-  KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
+  KIMAP::Session *session = new KIMAP::Session( "127.0.0.1", 5989 );
 
-  KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
-  login->setUserName(user);
-  login->setPassword(password);
+  KIMAP::LoginJob *login = new KIMAP::LoginJob( session );
+  login->setUserName( user );
+  login->setPassword( password );
   bool result = login->exec();
 
-  QEXPECT_FAIL("wrong login","Login with bad user name", Continue);
-  QEXPECT_FAIL("already authenticated","Trying to log on an already authenticated session", Continue);
-  QVERIFY(result);
+  QEXPECT_FAIL( "wrong login","Login with bad user name", Continue );
+  QEXPECT_FAIL( "already authenticated","Trying to log on an already authenticated session", Continue );
+  QVERIFY( result );
+
+  fakeServer.quit();
+  delete session;
+}
+
+void shouldHandleProxyLogin_data()
+{
+  QTest::addColumn<QString>( "user" );
+  QTest::addColumn<QString>( "proxy" );
+  QTest::addColumn<QString>( "password" );
+  QTest::addColumn< QList<QByteArray> >( "scenario" );
+
+  QList<QByteArray> scenario;
+  scenario << FakeServer::greeting()
+           << "C: A000001 AUTHENTICATE PLAIN"
+           << "C: A000001 LOGIN \"proxy\" \"user\" \"password\""
+           << "S: A000001 OK User logged in";
+
+  QTest::newRow( "success" ) << "user" << "proxy" << "password" << scenario;
+}
+
+void shouldHandleProxyLogin()
+{
+  QFETCH( QString, user );
+  QFETCH( QString, proxy );
+  QFETCH( QString, password );
+  QFETCH( QList<QByteArray>, scenario );
+
+  FakeServer fakeServer;
+  fakeServer.setScenario( scenario );
+  fakeServer.startAndWait();
+
+  KIMAP::Session *session = new KIMAP::Session( "127.0.0.1", 5989 );
+
+  KIMAP::LoginJob *login = new KIMAP::LoginJob( session );
+  login->setAuthenticationMode( KIMAP::LoginJob::Plain );
+  login->setUserName( user );
+  login->setAuthorizationName( proxy );
+  login->setPassword( password );
+  bool result = login->exec();
+
+  QVERIFY( result );
 
   fakeServer.quit();
   delete session;
@@ -135,14 +177,14 @@ void shouldSaveServerGreeting()
   fakeServer.setScenario( scenario );
   fakeServer.startAndWait();
 
-  KIMAP::Session *session = new KIMAP::Session("127.0.0.1", 5989);
+  KIMAP::Session *session = new KIMAP::Session( "127.0.0.1", 5989 );
 
-  KIMAP::LoginJob *login = new KIMAP::LoginJob(session);
-  login->setUserName("user");
-  login->setPassword("password");
+  KIMAP::LoginJob *login = new KIMAP::LoginJob( session );
+  login->setUserName( "user" );
+  login->setPassword( "password" );
   login->exec();
 
-  QCOMPARE(login->serverGreeting(), greeting);
+  QCOMPARE( login->serverGreeting(), greeting );
 
   fakeServer.quit();
   delete session;
