@@ -18,7 +18,6 @@
 */
 
 #include "messagetest.h"
-#include "messagetest.moc"
 #include <qtest_kde.h>
 #include <kdebug.h>
 
@@ -411,7 +410,7 @@ void MessageTest::testInlineImages()
   msg.setContent( data );
   msg.parse();
 
-  QCOMPARE( msg.contents().size(), 2);
+  QCOMPARE( msg.contents().size(), 2 );
   QCOMPARE( msg.contents()[0]->contentType()->isMultipart(), true );
   QCOMPARE( msg.contents()[0]->contentType()->subType().data(), "alternative" );
 
@@ -449,7 +448,7 @@ void MessageTest::testIssue3914()
   KMime::Content *attachedMail =  msg->contents().at( 1 );
   QCOMPARE( attachedMail->contentType()->mimeType().data(), "message/rfc822" );
   QVERIFY( attachedMail->contentDisposition( false ) );
-  QVERIFY( attachedMail->contentDisposition()->hasParameter( "filename") );
+  QVERIFY( attachedMail->contentDisposition()->hasParameter( "filename" ) );
   QVERIFY( attachedMail->contentDisposition()->parameter( "filename" ).isEmpty() );
 }
 
@@ -589,7 +588,8 @@ void MessageTest::testOutlookAttachmentNaming()
 KMime::Message::Ptr MessageTest::readAndParseMail( const QString &mailFile ) const
 {
   QFile file( MAIL_DATA_DIR"/" + mailFile );
-  Q_ASSERT( file.open( QIODevice::ReadOnly ) );
+  const bool ok = file.open( QIODevice::ReadOnly );
+  Q_ASSERT( ok );
   const QByteArray data = KMime::CRLFtoLF( file.readAll() );
   Q_ASSERT( !data.isEmpty() );
   KMime::Message::Ptr msg( new KMime::Message );
