@@ -21,22 +21,13 @@
 #ifndef INSERTHTMLDIALOG_H
 #define INSERTHTMLDIALOG_H
 
+#include "kpimtextedit_export.h"
 #include <KDialog>
-#include <QSyntaxHighlighter>
 
 namespace KPIMTextEdit {
 class InsertHtmlDialogPrivate;
 
-class HTMLSourceHighlighter : public QSyntaxHighlighter
-{
-public:
-  HTMLSourceHighlighter( QTextDocument * textdocument )
-    : QSyntaxHighlighter( textdocument ) {}
-protected:
-  virtual void highlightBlock ( const QString & text );
-};
-
-class InsertHtmlDialog : public KDialog
+class KPIMTEXTEDIT_EXPORT InsertHtmlDialog : public KDialog
 {
   Q_OBJECT
 public:
